@@ -2,7 +2,7 @@ import io
 
 from datomizer import DatoMapper
 from datomizer.helpers.common_helper import wait_for_step_type, get_generated_zip, get_generated_csv
-from datomizer.helpers.train.train_helper import train, get_train_iteration
+from datomizer.helpers.train.train_helper import train, get_train_iteration, get_evaluation
 from datomizer.helpers.wrapper.schema_wrapper import NAME
 from datomizer.utils.general import ID, MODELS, ERROR
 from datomizer.utils.step_types import TRAIN_AND_GENERATE
@@ -75,6 +75,10 @@ class DatoTrainer(object):
                                  train_id=self.train_id,
                                  table_name=table_name)
 
+    def get_evaluation(self) -> None:
+        self.next_step_validation()
+        return get_evaluation(dato_mapper=self.dato_mapper, model_id=self.model_id)
+
     def restore_validation(self):
         if not (self.train_id > 0):
             raise Exception("flow id required for this step")
